@@ -5,7 +5,7 @@ package Template::Reverse::Converter::Regexp;
 use Moo;
 use Scalar::Util qw(blessed);
 use utf8;
-our $VERSION = '0.150'; # VERSION
+our $VERSION = '0.200'; # VERSION
 
 sub Convert{
     my $self = shift;
@@ -13,11 +13,11 @@ sub Convert{
     my @temps;
 
     foreach my $pat (@{$parts}){
-        my @pre = @{$pat->pre};
-        my @post = @{$pat->post};
+        my @pre = @{$pat->{pre}};
+        my @post = @{$pat->{post}};
 
-        @pre = map{blessed($_)?$_->as_string:$_}@pre;
-        @post= map{blessed($_)?$_->as_string:$_}@post;
+        @pre = grep{!ref($_)}@pre;
+        @post= grep{!ref($_)}@post;
         my $pretxt = join '',@pre;
         my $posttxt = join '',@post;
         $pretxt .= '' if $pretxt;
@@ -50,7 +50,7 @@ Template::Reverse::Converter::Regexp - Convert parts to Regular Expression simpl
 
 =head1 VERSION
 
-version 0.150
+version 0.200
 
 =head1 SYNOPSIS
 
