@@ -4,7 +4,7 @@ package Template::Reverse::Converter::TT2;
 
 use Moo;
 use Scalar::Util qw(blessed);
-our $VERSION = '0.150'; # VERSION
+our $VERSION = '0.200'; # VERSION
 
 sub Convert{
     my $self = shift;
@@ -12,11 +12,11 @@ sub Convert{
     my @temps;
 
     foreach my $pat (@{$parts}){
-        my @pre = @{$pat->pre};
-        my @post = @{$pat->post};
+        my @pre = @{$pat->{pre}};
+        my @post = @{$pat->{post}};
 
-        @pre = map{blessed($_)?$_->as_string:$_}@pre;
-        @post= map{blessed($_)?$_->as_string:$_}@post;
+        @pre = grep{!ref($_)}@pre;
+        @post= grep{!ref($_)}@post;
         my $pretxt = join '',@pre;
         my $posttxt = join '',@post;
         $pretxt .= '' if $pretxt;
@@ -43,7 +43,7 @@ Template::Reverse::Converter::TT2 - Convert parts to TT2 format simply
 
 =head1 VERSION
 
-version 0.150
+version 0.200
 
 =head1 SYNOPSIS
 
